pub struct CreateOpts {
pub force: bool,
pub use_filestore: bool,
pub mainnet: bool,
pub regtest: bool,
pub signet: bool,
pub mutinynet: bool,
pub mnemonic: Option<Mnemonic>,
pub birthday_height: Option<BlockHeight>,
pub config: ConfigOpts,
}Fields
force: boolForce re-create the wallet even if it already exists. Any funds in the old wallet will be lost
use_filestore: boolUse filestore (JSON file) persistence instead of SQLite. This creates a marker file so subsequent commands use the same backend.
Warning: do not use this for a production wallet.
mainnet: boolUse bitcoin mainnet
regtest: boolUse regtest network
signet: boolUse the official signet network
mutinynet: boolUse mutinynet
mnemonic: Option<Mnemonic>Recover a wallet with an existing mnemonic. This currently only works for on-chain funds.
birthday_height: Option<BlockHeight>The wallet/mnemonic’s birthday blockheight to start syncing when recovering.
config: ConfigOptsTrait Implementations
Sourceimpl Args for CreateOpts
impl Args for CreateOpts
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for CreateOpts
impl FromArgMatches for CreateOpts
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for CreateOpts
impl RefUnwindSafe for CreateOpts
impl Send for CreateOpts
impl Sync for CreateOpts
impl Unpin for CreateOpts
impl UnsafeUnpin for CreateOpts
impl UnwindSafe for CreateOpts